"use client"

import { useState } from "react"
import { useAuth } from "@/context/auth-context"
import { useRouter } from "next/navigation"
import { Card, CardContent, CardDescription, CardFooter, CardHeader, CardTitle } from "@/components/ui/card"
import { Button } from "@/components/ui/button"
import { Check, CreditCard, Shield, Zap } from "lucide-react"
import Link from "next/link"

export default function SubscriptionPage() {
  const { user } = useAuth()
  const router = useRouter()
  const [selectedPlan, setSelectedPlan] = useState<string | null>(null)
  const [isProcessing, setIsProcessing] = useState(false)
  const [error, setError] = useState<string | null>(null)
  const [success, setSuccess] = useState(false)

  const handleSelectPlan = (plan: string) => {
    setSelectedPlan(plan)
    setError(null)
  }

  const handleSubscribe = async () => {
    if (!selectedPlan) {
      setError("Veuillez sélectionner un plan d'abonnement")
      return
    }

    setIsProcessing(true)
    setError(null)

    try {
      // Ici, vous implémenteriez l'intégration avec votre système de paiement
      // Pour cet exemple, nous simulons simplement une requête réussie

      // Calculer la nouvelle date d'expiration (1 an à partir d'aujourd'hui)
      const expirationDate = new Date()
      expirationDate.setFullYear(expirationDate.getFullYear() + 1)

      const response = await fetch(`/api/users/${user?.id}/subscription`, {
        method: "PUT",
        headers: {
          "Content-Type": "application/json",
        },
        body: JSON.stringify({
          planType: selectedPlan,
          expirationDate: expirationDate.toISOString(),
        }),
      })

      if (!response.ok) {
        throw new Error("Erreur lors du renouvellement de l'abonnement")
      }

      setSuccess(true)

      // Rediriger vers la page de profil après 2 secondes
      setTimeout(() => {
        router.push("/profile")
      }, 2000)
    } catch (error) {
      console.error("Erreur:", error)
      setError("Une erreur est survenue lors du traitement de votre abonnement. Veuillez réessayer.")
    } finally {
      setIsProcessing(false)
    }
  }

  return (
    <div className="min-h-screen bg-gray-50">
      <div className="bg-blue-600 py-16 px-4">
        <div className="container mx-auto text-center">
          <h1 className="text-4xl font-bold text-white mb-2">Abonnements</h1>
          <p className="text-xl text-blue-100">Choisissez le plan qui vous convient</p>
        </div>
      </div>

      <div className="container mx-auto py-12 px-4">
        {success ? (
          <Card className="max-w-md mx-auto">
            <CardHeader>
              <CardTitle className="text-center text-green-600">Abonnement réussi !</CardTitle>
            </CardHeader>
            <CardContent>
              <p className="text-center mb-4">
                Votre abonnement a été renouvelé avec succès. Vous allez être redirigé vers votre profil.
              </p>
            </CardContent>
            <CardFooter className="flex justify-center">
              <Link href="/profile">
                <Button>Aller à mon profil</Button>
              </Link>
            </CardFooter>
          </Card>
        ) : (
          <>
            <div className="text-center mb-12">
              <h2 className="text-3xl font-bold mb-4">Nos formules d'abonnement</h2>
              <p className="text-gray-600 max-w-2xl mx-auto">
                Accédez à toutes nos leçons et exercices pour réussir votre examen du code de la route.
              </p>
            </div>

            <div className="grid grid-cols-1 md:grid-cols-3 gap-8 max-w-5xl mx-auto">
              {/* Plan Gratuit */}
              <Card className={`border-2 ${selectedPlan === "free" ? "border-blue-500" : "border-transparent"}`}>
                <CardHeader>
                  <CardTitle className="flex items-center">
                    <Shield className="mr-2 h-5 w-5 text-gray-500" />
                    Gratuit
                  </CardTitle>
                  <CardDescription>Accès limité</CardDescription>
                  <div className="mt-4">
                    <span className="text-3xl font-bold">0€</span>
                    <span className="text-gray-500">/mois</span>
                  </div>
                </CardHeader>
                <CardContent>
                  <ul className="space-y-2">
                    <li className="flex items-center">
                      <Check className="h-5 w-5 text-green-500 mr-2" />
                      <span>Accès à 3 chapitres</span>
                    </li>
                    <li className="flex items-center">
                      <Check className="h-5 w-5 text-green-500 mr-2" />
                      <span>5 exercices par jour</span>
                    </li>
                    <li className="flex items-center">
                      <Check className="h-5 w-5 text-green-500 mr-2" />
                      <span>1 examen blanc</span>
                    </li>
                  </ul>
                </CardContent>
                <CardFooter>
                  <Button
                    variant="outline"
                    className="w-full"
                    onClick={() => handleSelectPlan("free")}
                    disabled={user?.planType === "free"}
                  >
                    {user?.planType === "free" ? "Plan actuel" : "Sélectionner"}
                  </Button>
                </CardFooter>
              </Card>

              {/* Plan Basique */}
              <Card
                className={`border-2 ${
                  selectedPlan === "basic" ? "border-blue-500" : "border-transparent"
                } shadow-lg relative`}
              >
                <div className="absolute top-0 right-0 bg-blue-500 text-white px-3 py-1 text-xs font-semibold rounded-bl-lg">
                  Populaire
                </div>
                <CardHeader>
                  <CardTitle className="flex items-center">
                    <CreditCard className="mr-2 h-5 w-5 text-blue-500" />
                    Basique
                  </CardTitle>
                  <CardDescription>Pour les débutants</CardDescription>
                  <div className="mt-4">
                    <span className="text-3xl font-bold">9,99€</span>
                    <span className="text-gray-500">/mois</span>
                  </div>
                </CardHeader>
                <CardContent>
                  <ul className="space-y-2">
                    <li className="flex items-center">
                      <Check className="h-5 w-5 text-green-500 mr-2" />
                      <span>Accès à tous les chapitres</span>
                    </li>
                    <li className="flex items-center">
                      <Check className="h-5 w-5 text-green-500 mr-2" />
                      <span>Exercices illimités</span>
                    </li>
                    <li className="flex items-center">
                      <Check className="h-5 w-5 text-green-500 mr-2" />
                      <span>5 examens blancs par mois</span>
                    </li>
                    <li className="flex items-center">
                      <Check className="h-5 w-5 text-green-500 mr-2" />
                      <span>Suivi de progression</span>
                    </li>
                  </ul>
                </CardContent>
                <CardFooter>
                  <Button className="w-full bg-blue-600 hover:bg-blue-700" onClick={() => handleSelectPlan("basic")}>
                    {user?.planType === "basic" ? "Renouveler" : "Sélectionner"}
                  </Button>
                </CardFooter>
              </Card>

              {/* Plan Premium */}
              <Card className={`border-2 ${selectedPlan === "premium" ? "border-blue-500" : "border-transparent"}`}>
                <CardHeader>
                  <CardTitle className="flex items-center">
                    <Zap className="mr-2 h-5 w-5 text-purple-500" />
                    Premium
                  </CardTitle>
                  <CardDescription>Pour une réussite garantie</CardDescription>
                  <div className="mt-4">
                    <span className="text-3xl font-bold">19,99€</span>
                    <span className="text-gray-500">/mois</span>
                  </div>
                </CardHeader>
                <CardContent>
                  <ul className="space-y-2">
                    <li className="flex items-center">
                      <Check className="h-5 w-5 text-green-500 mr-2" />
                      <span>Tout ce qui est inclus dans Basique</span>
                    </li>
                    <li className="flex items-center">
                      <Check className="h-5 w-5 text-green-500 mr-2" />
                      <span>Examens blancs illimités</span>
                    </li>
                    <li className="flex items-center">
                      <Check className="h-5 w-5 text-green-500 mr-2" />
                      <span>Corrections personnalisées</span>
                    </li>
                    <li className="flex items-center">
                      <Check className="h-5 w-5 text-green-500 mr-2" />
                      <span>Assistance prioritaire</span>
                    </li>
                    <li className="flex items-center">
                      <Check className="h-5 w-5 text-green-500 mr-2" />
                      <span>Garantie de réussite</span>
                    </li>
                  </ul>
                </CardContent>
                <CardFooter>
                  <Button
                    className="w-full bg-purple-600 hover:bg-purple-700"
                    onClick={() => handleSelectPlan("premium")}
                  >
                    {user?.planType === "premium" ? "Renouveler" : "Sélectionner"}
                  </Button>
                </CardFooter>
              </Card>
            </div>

            {error && (
              <div className="mt-8 max-w-md mx-auto bg-red-50 border-l-4 border-red-500 p-4 text-red-700">{error}</div>
            )}

            <div className="mt-12 text-center">
              <Button
                size="lg"
                className="bg-blue-600 hover:bg-blue-700"
                onClick={handleSubscribe}
                disabled={!selectedPlan || isProcessing}
              >
                {isProcessing ? "Traitement en cours..." : "Confirmer l'abonnement"}
              </Button>
              <p className="mt-4 text-sm text-gray-500">
                En confirmant, vous acceptez nos conditions générales d'utilisation et notre politique de
                confidentialité.
              </p>
            </div>
          </>
        )}
      </div>
    </div>
  )
}
